==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-taskbar/translations/taskbar_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>RazorTaskButton</name>
    <message>
        <location filename="../razortaskbutton.cpp" line="371"/>
        <source>Application</source>
        <translation>Anwendung</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="404"/>
        <source>To &amp;Desktop</source>
        <translation>Zur &amp;Arbeitsfläche</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="406"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Alle Arbeitsflächen</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="413"/>
        <source>Desktop &amp;%1</source>
        <translation>Arbeitsfläche &amp;%1</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="420"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Zur aktuellen Arbeitsfläche</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="429"/>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximieren</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="438"/>
        <source>Maximize vertically</source>
        <translation>Maximiere vertikal</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="443"/>
        <source>Maximize horizontally</source>
        <translation>Maximiere horizintal</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="449"/>
        <source>&amp;Restore</source>
        <translation>&amp;Wiederherstellen</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="453"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimieren</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="459"/>
        <source>Roll down</source>
        <translation>Roll runter</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="465"/>
        <source>Roll up</source>
        <translation>Roll hoch</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="474"/>
        <source>&amp;Layer</source>
        <translation>&amp;Schicht</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="476"/>
        <source>Always on &amp;top</source>
        <translation>Immer &amp;oben</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="481"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="486"/>
        <source>Always on &amp;bottom</source>
        <translation>Immer &amp;unten</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="494"/>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
</context>
<context>
    <name>RazorTaskbarConfiguration</name>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="14"/>
        <source>Razor Task Manager Settings</source>
        <translation>Razor Anwendungsverwalter Einstellungen</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="20"/>
        <source>Window List Content</source>
        <translation>Fester Inhalt</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="26"/>
        <source>Show windows from current desktop</source>
        <translation>Zeige Fenster von der aktuellen Arbeitsfläche</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="29"/>
        <location filename="../razortaskbarconfiguration.ui" line="39"/>
        <source>wlcB</source>
        <translation>wlcB</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="36"/>
        <source>Show windows from all desktops</source>
        <translation>Zeige Fester von allen Arbeitsflächen</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="49"/>
        <source>Window List Appearance</source>
        <translation>Festerlisten Erscheinungsbild</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="55"/>
        <source>Button style</source>
        <translation>Knopf Stil</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="65"/>
        <source>Max button width</source>
        <translation>Max Knopf breite</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="43"/>
        <source>Icon and text</source>
        <translation>Symbole und Text</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="44"/>
        <source>Only icon</source>
        <translation>Nur Symbole</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="45"/>
        <source>Only text</source>
        <translation>Nur Text</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-taskbar/translations/taskbar_de_DE.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de_DE" version="2.0">
<context>
    <name>RazorTaskButton</name>
    <message>
        <source>Application</source>
        <translation>Anwendung</translation>
    </message>
    <message>
        <source>To &amp;Desktop</source>
        <translation>Zur &amp;Arbeitsfläche</translation>
    </message>
    <message>
        <source>&amp;All Desktops</source>
        <translation>&amp;Alle Arbeitsflächen</translation>
    </message>
    <message>
        <source>Desktop &amp;%1</source>
        <translation>Arbeitsfläche &amp;%1</translation>
    </message>
    <message>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Zur aktuellen Arbeitsfläche</translation>
    </message>
    <message>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximieren</translation>
    </message>
    <message>
        <source>Maximize vertically</source>
        <translation>Maximiere vertikal</translation>
    </message>
    <message>
        <source>Maximize horizontally</source>
        <translation>Maximiere horizintal</translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Wiederherstellen</translation>
    </message>
    <message>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimieren</translation>
    </message>
    <message>
        <source>Roll down</source>
        <translation>Roll runter</translation>
    </message>
    <message>
        <source>Roll up</source>
        <translation>Roll hoch</translation>
    </message>
    <message>
        <source>&amp;Layer</source>
        <translation>&amp;Schicht</translation>
    </message>
    <message>
        <source>Always on &amp;top</source>
        <translation>Immer &amp;oben</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <source>Always on &amp;bottom</source>
        <translation>Immer &amp;unten</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
</context>
<context>
    <name>RazorTaskbarConfiguration</name>
    <message>
        <source>Razor Task Manager Settings</source>
        <translation>Razor Anwendungsverwalter Einstellungen</translation>
    </message>
    <message>
        <source>Window List Content</source>
        <translation>Fester Inhalt</translation>
    </message>
    <message>
        <source>Show windows from current desktop</source>
        <translation>Zeige Fenster von der aktuellen Arbeitsfläche</translation>
    </message>
    <message>
        <source>Show windows from all desktops</source>
        <translation>Zeige Fester von allen Arbeitsflächen</translation>
    </message>
    <message>
        <source>Window List Appearance</source>
        <translation>Festerlisten Erscheinungsbild</translation>
    </message>
    <message>
        <source>Button style</source>
        <translation>Knopf Stil</translation>
    </message>
    <message>
        <source>Max button width</source>
        <translation>Max Knopf breite</translation>
    </message>
    <message>
        <source>Close on middle-click</source>
        <translation>Schließen mit Mittelklick</translation>
    </message>
    <message>
        <source>Icon and text</source>
        <translation>Symbole und Text</translation>
    </message>
    <message>
        <source>Only icon</source>
        <translation>Nur Symbole</translation>
    </message>
    <message>
        <source>Only text</source>
        <translation>Nur Text</translation>
    </message>
</context>
</TS>
